@@ -26,6 +26,8 @@ from dateutil.relativedelta import relativedelta
 from dateutil.parser import parse as parse_date
 from decimal import Decimal, InvalidOperation
 
+from urllib.request import getproxies
+
 from woob.browser.browsers import APIBrowser
 from woob.browser.profiles import Woob
 from woob.exceptions import (
@@ -41,13 +43,12 @@ from woob.capabilities.bank import (
     TransferInvalidLabel, TransferInvalidAmount, TransferInvalidDate,
     TransferInvalidEmitter, TransferInvalidRecipient,
 )
-from woob.capabilities.wealth import CapBankWealth
+from woob.capabilities.bank.wealth import CapBankWealth
 from woob.capabilities.captcha import exception_to_job
 from woob.capabilities.profile import CapProfile
 from woob.tools.application.repl import ReplApplication, defaultcount
 from woob.tools.application.captcha import CaptchaMixin
 from woob.tools.application.formatters.iformatter import IFormatter, PrettyFormatter
-from woob.tools.compat import getproxies
 from woob.tools.log import getLogger
 from woob.tools.misc import to_unicode
 
@@ -502,7 +503,7 @@ class EmitterListFormatter(IFormatter):
 class Appbank(CaptchaMixin, ReplApplication):
     APPNAME = 'bank'
     OLD_APPNAME = 'boobank'
-    VERSION = '3.0'
+    VERSION = '3.1'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Romain Bignon, Christophe Benz'
     CAPS = CapBank
     DESCRIPTION = "Console application allowing to list your bank accounts and get their balance, " \
@@ -995,6 +996,24 @@ class Appbank(CaptchaMixin, ReplApplication):
         for emitter in self.do('iter_emitters', backends=list(self.enabled_backends), caps=CapTransfer):
             self.cached_format(emitter)
 
+    def do_convert_currency(self, line):
+        """
+        convert_currency FROM_CURRENCY TO_CURRENCY [AMOUNT]
+
+        Convert an amount from a currency to another
+        """
+
+        currency_from, currency_to, amount = self.parse_command_args(line, 3, 2)
+        if amount is None:
+            amount = 1
+        amount = Decimal(amount)
+
+        for rate in self.do("get_rate", currency_from, currency_to):
+            if rate is not None:
+                converted_amount = rate.convert(amount)
+                print("%s %s is equal to %s %s" % (amount, rate.currency_from, converted_amount, rate.currency_to))
+                break
+
     def main(self, argv):
         self.load_config()
         return super(Appbank, self).main(argv)
