@@ -22,23 +22,20 @@ from __future__ import absolute_import
 import datetime
 import re
 import unicodedata
-import unidecode
-try:
-    # Python 3.3 and above
-    from collections.abc import Iterator
-except ImportError:
-    from collections import Iterator
+from collections.abc import Iterator
 from decimal import Decimal, InvalidOperation
 from itertools import islice
 from numbers import Number
+from urllib.parse import parse_qs, urlparse
 
 from dateutil.parser import parse as parse_date
 from dateutil.tz import gettz
+from lxml.etree import ElementBase as LXMLElement
+import unidecode
 
 from woob.browser.url import URL
 from woob.capabilities.base import Currency as BaseCurrency
 from woob.capabilities.base import empty
-from woob.tools.compat import basestring, long, parse_qs, unicode, urlparse
 
 from .base import _NO_DEFAULT, Filter, FilterError, ItemNotFound, _Filter, debug
 
@@ -208,7 +205,7 @@ class RawText(Filter):
         if text is None:
             result = self.default
         else:
-            result = unicode(text)
+            result = str(text)
 
         return result
 
@@ -221,7 +218,7 @@ class CleanText(Filter):
     (including newlines if ``newlines`` is True)
     to one space and strips the result string.
 
-    The result is coerced into unicode, and optionally normalized
+    The result is coerced into str, and optionally normalized
     according to the ``normalize`` argument.
 
     Then it replaces all symbols given in the ``symbols`` argument.
@@ -267,30 +264,37 @@ class CleanText(Filter):
         elif isinstance(txt, int):
             txt = str(txt)
         elif isinstance(txt, (tuple, list)):
-            txt = u' '.join([self.clean(item, children=self.children) for item in txt])
+            txt = u' '.join(
+                self.clean(item, newlines=self.newlines, children=self.children)
+                for item in txt
+            )
 
         txt = self.clean(txt, self.children, self.newlines, self.normalize, self.transliterate)
         txt = self.remove(txt, self.symbols)
         txt = self.replace(txt, self.toreplace)
-        # ensure it didn't become str by mistake
-        return unicode(txt)
+        return txt
 
     @classmethod
     def clean(cls, txt, children=True, newlines=True, normalize='NFC', transliterate=False):
-        if not isinstance(txt, basestring):
+        """
+        Cleans the text. The children argument is ignored with Selenium.
+        """
+        if isinstance(txt, LXMLElement):
             if children:
-                txt = [t.strip() for t in txt.itertext()]
+                txt = list(txt.itertext())
             else:
-                txt = [t.strip() for t in txt.xpath('./text()')]
-            txt = u' '.join(txt)  # 'foo   bar'
+                txt = list(txt.xpath('./text()'))
+            txt = u' '.join(txt)  # 'foo   bar '
+        elif not isinstance(txt, str):
+            txt = u' '.join(txt.itertext())
+
         if newlines:
-            txt = re.compile(u'\s+', flags=re.UNICODE).sub(u' ', txt)  # 'foo bar'
+            txt = re.compile(r'\s+', flags=re.UNICODE).sub(u' ', txt)  # 'foo bar '
         else:
             # normalize newlines and clean what is inside
             txt = '\n'.join([cls.clean(l) for l in txt.splitlines()])
+
         txt = txt.strip()
-        # lxml under Python 2 returns str instead of unicode if it is pure ASCII
-        txt = unicode(txt)
         # normalize to a standard Unicode form
         if normalize:
             txt = unicodedata.normalize(normalize, txt)
@@ -342,6 +346,8 @@ class Currency(CleanText):
     @debug()
     def filter(self, txt):
         txt = super(Currency, self).filter(txt)
+        if empty(txt):
+            return self.default_or_raise(FormatError("Unable to parse %r" % txt))
         return BaseCurrency.get_currency(txt)
 
 
@@ -384,7 +390,7 @@ class CleanDecimal(CleanText):
 
     @debug()
     def filter(self, text):
-        if type(text) in (float, int, long):
+        if type(text) in (float, int):
             text = str(text)
 
         if empty(text):
@@ -611,6 +617,8 @@ class Regexp(Filter):
             return self.default_or_raise(RegexpError(msg))
 
         if not m:
+            if len(txt) > 1024:
+                txt = txt[:1021] + "..."
             msg = 'Unable to find %s %s in %r' % (ordinal(self.nth), self.pattern, txt)
             return self.default_or_raise(RegexpError(msg))
 
@@ -698,7 +706,7 @@ class DateTime(Filter):
         self.translations = translations
         self.parse_func = parse_func
         self.strict = strict
-        if isinstance(tzinfo, basestring):
+        if isinstance(tzinfo, str):
             tzinfo = gettz(tzinfo)
         self.tzinfo = tzinfo
 
@@ -784,7 +792,7 @@ class DateGuesser(Filter):
         if isinstance(date_guesser, _Filter):
             date_guesser = self.select(date_guesser, item)
 
-        if isinstance(values, basestring):
+        if isinstance(values, str):
             values = re.split('[/-]', values)
         if len(values) == 2:
             day, month = map(int, values)
@@ -878,6 +886,23 @@ class Format(MultiFilter):
 
 
 class BrowserURL(MultiFilter):
+    r""" Format URL using names in parent Browser
+
+    This filter allows to format URL using an URL defined
+    in browser instance of this page.
+
+    .. code-block:: python
+
+    class MyBrowser:
+
+        mypage = URL('(?P<category>\w+)/(?P<id>\w+)')
+
+
+    class OnePage(Page):
+        class item(ItemElement):
+            obj_myfield = BrowserURL('mypage', id=Dict('id'), category=Dict('category'))
+
+    """
     def __init__(self, url_name, **kwargs):
         super(BrowserURL, self).__init__(*kwargs.values())
         self.url_name = url_name
@@ -959,7 +984,7 @@ class MultiJoin(MultiFilter):
 
     @debug()
     def filter(self, values):
-        values = [unicode(v) for v in values if v]
+        values = [str(v) for v in values if v]
         if not values and self.default is not _NO_DEFAULT:
             return self.default
         return self.pattern.join(values)
@@ -1028,117 +1053,3 @@ class Coalesce(MultiFilter):
             if value or (isinstance(value, Number) and not empty(value)):
                 return value
         return self.default_or_raise(FilterError('All falsy and no default.'))
-
-
-def test_CleanText():
-    # This test works poorly under a doctest, or would be hard to read
-    assert CleanText().filter(u' coucou  \n\théhé') == u'coucou héhé'
-    assert CleanText().filter('coucou\xa0coucou') == CleanText().filter(u'coucou\xa0coucou') == u'coucou coucou'
-
-    # Unicode normalization
-    assert CleanText().filter(u'Éçã') == u'Éçã'
-    assert CleanText(normalize='NFKC').filter(u'…') == u'...'
-    assert CleanText().filter(u'…') == u'…'
-    # Diacritical mark (dakuten)
-    assert CleanText().filter(u'\u3053\u3099') == u'\u3054'
-    assert CleanText(normalize='NFD').filter(u'\u3053\u3099') == u'\u3053\u3099'
-    assert CleanText(normalize='NFD').filter(u'\u3054') == u'\u3053\u3099'
-    assert CleanText(normalize=False).filter(u'\u3053\u3099') == u'\u3053\u3099'
-    # None value
-    assert_raises(FilterError, CleanText().filter, None)
-
-
-def assert_raises(exc_class, func, *args, **kwargs):
-    try:
-        func(*args, **kwargs)
-    except exc_class:
-        pass
-    else:
-        assert False, 'did not raise %s' % exc_class
-
-
-def test_CleanDecimal_unicode():
-    assert CleanDecimal().filter(u'\u22123000') == Decimal('-3000')
-
-
-def test_CleanDecimal_sign():
-    assert CleanDecimal(sign='-').filter('42') == Decimal('-42')
-    assert CleanDecimal(sign='-').filter('-42') == Decimal('-42')
-    assert CleanDecimal(sign='+').filter('42') == Decimal('42')
-    assert CleanDecimal(sign='+').filter('-42') == Decimal('42')
-
-
-def test_CleanDecimal_strict():
-    assert CleanDecimal.US().filter('123') == Decimal('123')
-    assert CleanDecimal.US().filter('foo + 123 bar') == Decimal('123')
-    assert CleanDecimal.US().filter('foo +123 bar') == Decimal('123')
-    assert CleanDecimal.US().filter('foo 123.45 bar') == Decimal('123.45')
-    assert CleanDecimal.US().filter('foo 12,345.67 bar') == Decimal('12345.67')
-    assert CleanDecimal.US().filter('foo 123,456,789 bar') == Decimal('123456789')
-    assert CleanDecimal.US().filter('foo - 123,456,789.1 bar') == Decimal('-123456789.1')
-    assert CleanDecimal.US().filter('foo -123,456,789.1 bar') == Decimal('-123456789.1')
-    assert CleanDecimal.US().filter('foo - .1 bar') == Decimal('-0.1')
-    assert CleanDecimal.US().filter('foo -.1 bar') == Decimal('-0.1')
-    assert_raises(NumberFormatError, CleanDecimal.US().filter, 'foo 12 345.67 bar')
-    assert_raises(NumberFormatError, CleanDecimal.US().filter, 'foo 123 bar 456')
-    assert_raises(NumberFormatError, CleanDecimal.US().filter, 'foo 123.456.789 bar')
-    assert_raises(NumberFormatError, CleanDecimal.US().filter, 'foo 12,3456 bar')
-    assert_raises(NumberFormatError, CleanDecimal.US().filter, 'foo 123-456 bar')
-
-    assert CleanDecimal.French().filter('123') == Decimal('123')
-    assert CleanDecimal.French().filter('foo + 123 bar') == Decimal('123')
-    assert CleanDecimal.French().filter('foo +123 bar') == Decimal('123')
-    assert CleanDecimal.French().filter('foo 123,45 bar') == Decimal('123.45')
-    assert CleanDecimal.French().filter('foo 12 345,67 bar') == Decimal('12345.67')
-    assert CleanDecimal.French().filter('foo - 123 456 789 bar') == Decimal('-123456789')
-    assert CleanDecimal.French().filter('foo -123 456 789 bar') == Decimal('-123456789')
-    assert_raises(NumberFormatError, CleanDecimal.French().filter, 'foo 123.45 bar')
-    assert_raises(NumberFormatError, CleanDecimal.French().filter, 'foo 123 bar 456')
-    assert_raises(NumberFormatError, CleanDecimal.French().filter, 'foo 123,456,789')
-    assert_raises(NumberFormatError, CleanDecimal.French().filter, 'foo 12 3456 bar')
-    assert_raises(NumberFormatError, CleanDecimal.French().filter, 'foo 123-456 bar')
-
-    assert CleanDecimal.SI().filter('123') == Decimal('123')
-    assert CleanDecimal.SI().filter('foo + 123 bar') == Decimal('123')
-    assert CleanDecimal.SI().filter('foo +123 bar') == Decimal('123')
-    assert CleanDecimal.SI().filter('foo 123.45 bar') == Decimal('123.45')
-    assert CleanDecimal.SI().filter('foo 12 345.67 bar') == Decimal('12345.67')
-    assert CleanDecimal.SI().filter('foo 123 456 789 bar') == Decimal('123456789')
-    assert CleanDecimal.SI().filter('foo - 123 456 789 bar') == Decimal('-123456789')
-    assert CleanDecimal.SI().filter('foo -123 456 789 bar') == Decimal('-123456789')
-    assert_raises(NumberFormatError, CleanDecimal.SI().filter, 'foo 123,45 bar')
-    assert_raises(NumberFormatError, CleanDecimal.SI().filter, 'foo 123 bar 456')
-    assert_raises(NumberFormatError, CleanDecimal.SI().filter, 'foo 123,456,789')
-    assert_raises(NumberFormatError, CleanDecimal.SI().filter, 'foo 12 3456 bar')
-    assert_raises(NumberFormatError, CleanDecimal.SI().filter, 'foo 123-456 bar')
-
-
-def test_DateTime():
-    today = datetime.datetime.now()
-    assert_raises(FilterError, Date(strict=True).filter, '2019')
-    assert_raises(FilterError, Date(strict=True).filter, '1788-7')
-    assert_raises(FilterError, Date(strict=True).filter, 'June 1st')
-
-    assert Date(strict=True).filter('1788-7-15') == datetime.date(1788, 7, 15)
-
-    assert Date(strict=False).filter('1788-7-15') == datetime.date(1788, 7, 15)
-    assert Date(strict=False).filter('1945-7') == datetime.date(1945, 7, today.day)
-    assert Date(strict=False).filter('June 1st') == datetime.date(today.year, 6, 1)
-
-    assert DateTime(strict=False).filter('1788-7') == datetime.datetime(1788, 7, today.day)
-    assert DateTime(strict=False).filter('1788') == datetime.datetime(1788, today.month, today.day)
-    assert DateTime(strict=False).filter('5-1') == datetime.datetime(today.year, 5, 1)
-
-    assert Date(yearfirst=True).filter('88-7-15') == datetime.date(1988, 7, 15)
-    assert Date(yearfirst=False).filter('20-7-15') == datetime.date(2015, 7, 20)
-    assert Date(yearfirst=True).filter('1789-7-15') == datetime.date(1789, 7, 15)
-    assert Date(yearfirst=True, strict=False).filter('7-15') == datetime.date(today.year, 7, 15)
-
-
-def test_regex():
-    try:
-        assert Regexp(pattern=r'([[a-z]--[aeiou]]+)(?V1)').filter(u'abcde') == u'bcd'
-        assert not Regexp(pattern=r'([[a-z]--[aeiou]]+)(?V0)', default=False).filter(u'abcde')
-    except ImportError:
-        pass
-    assert not Regexp(pattern=r'([[a-z]--[aeiou]]+)', default=False).filter(u'abcde')
