@@ -16,14 +16,14 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-
+import importlib
 import os
 from copy import copy
 from threading import RLock
 
+from urllib.request import getproxies
+
 from woob.capabilities.base import BaseObject, Capability, FieldNotFound, NotAvailable, NotLoaded
-from woob.exceptions import ModuleInstallError
-from woob.tools.compat import basestring, getproxies
 from woob.tools.log import getLogger
 from woob.tools.json import json
 from woob.tools.misc import iter_fields
@@ -157,8 +157,11 @@ class BackendConfig(ValuesDict):
 
             if value is None:
                 if not nofail and field.required:
-                    raise Module.ConfigError('Backend(%s): Configuration error: Missing parameter "%s" (%s)'
-                                                  % (cfg.instname, name, field.description))
+                    raise Module.ConfigError(
+                        'Backend(%s): Configuration error: Missing parameter "%s" (%s)'
+                        % (cfg.instname, name, field.description),
+                       bad_fields=[name]
+                    )
                 value = field.default
 
             field = copy(field)
@@ -167,7 +170,9 @@ class BackendConfig(ValuesDict):
             except ValueError as v:
                 if not nofail:
                     raise Module.ConfigError(
-                        'Backend(%s): Configuration error for field "%s": %s' % (cfg.instname, name, v))
+                        'Backend(%s): Configuration error for field "%s": %s' % (cfg.instname, name, v),
+                        bad_fields=[name]
+                    )
 
             cfg[name] = field
         return cfg
@@ -270,11 +275,25 @@ class Module(object):
     NOT yet filled.
     """
 
+    DEPENDENCIES = ()
+    """Tuple of module names on which this module depends."""
+
     class ConfigError(Exception):
         """
         Raised when the config can't be loaded.
         """
 
+        def __init__(self, message, bad_fields=None):
+            """
+            :type message: str
+            :param message: message of the exception
+            :type bad_fields: list[str]
+            :param bad_fields: names of the config fields which are incorrect
+            """
+
+            super(Module.ConfigError, self).__init__(message)
+            self.bad_fields = bad_fields or ()
+
     def __enter__(self):
         self.lock.acquire()
 
@@ -373,7 +392,7 @@ class Module(object):
         kwargs['proxy'] = self.get_proxy()
         if '_proxy_headers' in self._private_config:
             kwargs['proxy_headers'] = self._private_config['_proxy_headers']
-            if isinstance(kwargs['proxy_headers'], basestring):
+            if isinstance(kwargs['proxy_headers'], str):
                 kwargs['proxy_headers'] = json.loads(kwargs['proxy_headers'])
 
         kwargs['logger'] = self.logger
@@ -423,7 +442,7 @@ class Module(object):
         Check if this backend implements at least one of these capabilities.
         """
         for c in caps:
-            if (isinstance(c, basestring) and c in [cap.__name__ for cap in self.iter_caps()]) or \
+            if (isinstance(c, str) and c in [cap.__name__ for cap in self.iter_caps()]) or \
                isinstance(self, c):
                 return True
         return False
@@ -472,7 +491,7 @@ class Module(object):
 
             return missing_fields
 
-        if isinstance(fields, basestring):
+        if isinstance(fields, str):
             fields = (fields,)
 
         missing_fields = filter_missing_fields(obj, fields, not_loaded_or_incomplete)
@@ -500,61 +519,25 @@ class AbstractModuleMissingParentError(Exception):
     pass
 
 
-class AbstractModule(Module):
-    """ Abstract module allow inheritance between modules.
+class MetaModule(type):
+    # we can remove this class as soon as we get rid of Abstract*
+    def __new__(mcs, name, bases, dct):
+        if name != 'AbstractModule' and AbstractModule in bases:
+            module = importlib.import_module('woob_modules.%s' % dct['PARENT'])
+            symbols = [getattr(module, attr) for attr in dir(module) if not attr.startswith('__')]
+            klass = next(
+                symbol for symbol in symbols
+                if isinstance(symbol, type) and issubclass(symbol, Module) and symbol != Module
+            )
 
-    Sometimes, several websites are based on the same website engine. This module
-    allow to simplify code with a fake inheritance: woob will install (if needed) and
-    load a PARENT module and build our AbstractModule on top of this class.
+            bases = tuple(klass if isinstance(base, mcs) else base for base in bases)
 
-    PARENT is a mandatory attribute of any AbstractModule.
+            additional_config = dct.pop('ADDITIONAL_CONFIG', None)
+            if additional_config:
+                dct['CONFIG'] = BackendConfig(*(list(klass.CONFIG.values()) + list(additional_config.values())))
 
-    By default an AbstractModule inherits its parent backends CONFIG.
-    To add backend values, use ADDITIONAL_CONFIG.
-    To remove backend values, you must override CONFIG definition.
+        return super(MetaModule, mcs).__new__(mcs, name, bases, dct)
 
-    Note that you must pass a valid woob instance as first argument of the constructor.
-    """
-    PARENT = None
 
-    ADDITIONAL_CONFIG = BackendConfig()
-    """Optional additional Values for backends, appended to parent CONFIG
-
-    Values must be woob.tools.value.Value objects.
-    """
-
-    @classmethod
-    def _resolve_abstract(cls, woob, name):
-        """ Replace AbstractModule parent with the real base class """
-        if cls.PARENT is None:
-            raise AbstractModuleMissingParentError("PARENT is not defined for module %s" % cls.__name__)
-
-        try:
-            parent = woob.load_or_install_module(cls.PARENT).klass
-        except ModuleInstallError as err:
-            raise ModuleInstallError('The module %s depends on %s module but %s\'s installation failed with: %s' % (name, cls.PARENT, cls.PARENT, err))
-
-        # Parent may be an AbstractModule as well
-        if hasattr(parent, '_resolve_abstract'):
-            parent._resolve_abstract(woob, name)
-
-        parent_caps = parent.iter_caps()
-        cls.__bases__ = tuple([parent] + [cap for cap in cls.iter_caps() if cap not in parent_caps])
-
-        # As soon as __bases__ is overwritten, the attributes and behavior of
-        # cls can change as the new "parents" will be taken into account immediately
-
-        # Cls may have defined an ADDITIONAL_CONFIG
-        # In that case, create a virtual CONFIG for this class that will
-        # contains the additional_config elements.
-        if getattr(cls, 'ADDITIONAL_CONFIG', None):
-            cls.CONFIG = BackendConfig(*(list(parent.CONFIG.values()) + list(cls.ADDITIONAL_CONFIG.values())))
-
-        return parent
-
-    def __new__(cls, woob, name, config=None, storage=None, logger=None, nofail=False):
-        # fake backend config inheritance, override existing Values
-        # do not use CONFIG to allow the children to overwrite completely the parent CONFIG.
-        cls._resolve_abstract(woob=woob, name=name)
-
-        return Module.__new__(cls, woob, name, config, storage, logger, nofail)
+class AbstractModule(metaclass=MetaModule):
+    """Don't use this class, import woob_modules.other_module.etc instead"""
