@@ -17,7 +17,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-import sys
 from io import BytesIO, StringIO
 from collections import namedtuple
 import logging
@@ -25,8 +24,6 @@ import os
 import subprocess
 from tempfile import mkstemp
 
-from .compat import range
-
 
 __all__ = ['decompress_pdf', 'get_pdf_rows']
 
@@ -284,7 +281,7 @@ def arrange_texts_in_rows(rows, trects):
     return table
 
 
-LOGGER = logging.getLogger('pdf')
+LOGGER = logging.getLogger(__name__)
 DEBUGFILES = logging.DEBUG - 1
 
 
@@ -543,10 +540,7 @@ def extract_text(data):
             return
 
         rsrcmgr = PDFResourceManager()
-        if sys.version_info.major == 2:
-            out = BytesIO()
-        else:
-            out = StringIO()
+        out = StringIO()
         device = TextConverter(rsrcmgr, out)
         interpreter = PDFPageInterpreter(rsrcmgr, device)
         if newapi:
